@@ -1,6 +1,6 @@
 package OpenGL::GLU;
 
-use 5.008;
+use 5.014;
 use strict;
 use warnings;
 use Carp;
@@ -229,7 +229,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	gluTessEndPolygon
 	gluTessNormal
 	gluTessProperty
-	gluTessVertex_p
+	gluTessVertex
 	gluUnProject
 	gluUnProject4
 ) ] );
@@ -394,7 +394,7 @@ our @EXPORT = qw(
 	GLU_V_STEP
 );
 
-our $VERSION = '0.02_02';
+our $VERSION = '0.01';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
